.. _profile_select:

**select** - Select a profile
=============================

Usage
--------

.. code::

    e4s-cl profile select <NAME>

Description
--------------

.. automodule:: e4s_cl.cli.commands.profile.select
